@@ -7,6 +7,7 @@ from .team import Team, TeamMember
 from .user import User
 from .bot import PararamioBot
 from .activity import Activity, ActivityAction
+from .poll import Poll
 
 
 __all__ = (
@@ -20,5 +21,6 @@ __all__ = (
     'TeamMember',
     'PararamioBot',
     'ActivityAction',
-    'Activity'
+    'Activity',
+    'Poll',
 )
