@@ -98,3 +98,11 @@ class PararamioSecondFactorAuthenticationException(PararamioAuthenticationExcept
 
 class PararamioCaptchaAuthenticationException(PararamioAuthenticationException):
     pass
+
+
+class PararamNoNextPost(PararamioException, StopIteration):
+    pass
+
+
+class PararamNoPrevPost(PararamioException, StopIteration):
+    pass
